@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_CONTACTGROUPSEARCHJOB_H
@@ -28,7 +15,8 @@
 #include <itemsearchjob.h>
 #include <kcontacts/contactgroup.h>
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
  * @short Job that searches for contact groups in the Akonadi storage.
  *
@@ -85,9 +73,9 @@ public:
      * @since 4.5
      */
     enum Match {
-        ExactMatch,      ///< The result must match exactly the pattern (case sensitive).
+        ExactMatch, ///< The result must match exactly the pattern (case sensitive).
         StartsWithMatch, ///< The result must start with the pattern (case insensitive).
-        ContainsMatch    ///< The result must contain the pattern (case insensitive).
+        ContainsMatch ///< The result must contain the pattern (case insensitive).
     };
 
     /**
