@@ -11,10 +11,11 @@
 
 #include <QWidget>
 
-#include <kcontacts/addressee.h>
 #include <ContactEditor/CategoriesEditAbstractWidget>
 #include <QVariant>
-namespace Akonadi {
+#include <kcontacts/addressee.h>
+namespace Akonadi
+{
 class TagWidget;
 }
 
@@ -26,9 +27,7 @@ class CategoriesEditWidget : public ContactEditor::CategoriesEditAbstractWidget
     Q_OBJECT
 
 public:
-    explicit CategoriesEditWidget(QWidget *parent = nullptr, const QList<QVariant> & =
-    {
-    });
+    explicit CategoriesEditWidget(QWidget *parent = nullptr, const QList<QVariant> & = {});
     ~CategoriesEditWidget() override;
 
     void loadContact(const KContacts::Addressee &contact) override;
@@ -37,7 +36,7 @@ public:
     void setReadOnly(bool readOnly) override;
 
 private:
-    Akonadi::TagWidget *mTagWidget = nullptr;
+    Akonadi::TagWidget *const mTagWidget;
 };
 
 #endif
