@@ -1,15 +1,16 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
     SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef SELECTADDRESSBOOKDIALOG_H
 #define SELECTADDRESSBOOKDIALOG_H
 
-#include <AkonadiWidgets/CollectionDialog>
 #include "akonadi-contact_export.h"
+#include <AkonadiWidgets/CollectionDialog>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class SelectAddressBookDialogPrivate;
 /**
  * @brief The SelectAddressBookDialog class This class allows to select addressbook where saving contacts
@@ -20,7 +21,7 @@ class AKONADI_CONTACT_EXPORT SelectAddressBookDialog : public Akonadi::Collectio
     Q_OBJECT
 public:
     explicit SelectAddressBookDialog(QWidget *parent = nullptr);
-    ~SelectAddressBookDialog();
+    ~SelectAddressBookDialog() override;
 
 private:
     SelectAddressBookDialogPrivate *const d;
