@@ -12,17 +12,19 @@
 
 #include "../../widgets/kwidgetlister_p.h"
 #include "contacteditor_private_export.h"
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
-namespace ContactEditor {
+namespace ContactEditor
+{
 class PhoneWidget;
 class CONTACTEDITOR_TESTS_EXPORT PhoneWidgetLister : public KWidgetLister
 {
     Q_OBJECT
 public:
     explicit PhoneWidgetLister(QWidget *parent = nullptr);
-    ~PhoneWidgetLister();
+    ~PhoneWidgetLister() override;
 
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
