@@ -14,7 +14,8 @@
 
 #include <kcontacts/resourcelocatorurl.h>
 class QToolButton;
-namespace ContactEditor {
+namespace ContactEditor
+{
 class WebSelectTypeCombobox;
 class PreferredLineEditWidget;
 class WebWidget : public QWidget
